@@ -7,7 +7,7 @@ class Venue(models.Model):
     venue_path = models.TextField(max_length=255)
     def __init__(self, venue_path, venue_name):
         self.venue_root = os.path.abspath(os.path.join(venue_path, venue_name))
-        self.uwsgi_ini = os.path.join(self.venue_root, 'backstage-%s-uwsgi.ini' % (self.venue_name))
+        self.uwsgi_ini = os.path.join(self.venue_root, 'backstage-%s-uwsgi.ini' % (venue_name))
         self.acts_dir = os.path.join(self.venue_root,'acts')
 
         if not os.path.exists(venue_root):
